iXBRL Viewer Test Document

iso4217:GBP 1234 2018-01-01 2018-12-31 1234 2017-01-01 2017-12-31 1234 2018-12-31 1234 2017-12-31 1234 2018-01-01 2018-12-31 1234 2017-01-01 2017-12-31 1234 2016-01-01 2016-12-31 1234 2015-01-01 2015-12-31 1234 2014-01-01 2014-12-31 1234 2013-01-01 2013-12-31 1234 2018-09-01 2018-12-31 1234 2017-09-01 2017-12-31

This is a text tag

Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Phasellus egestas tellus rutrum tellus pellentesque eu tincidunt. Mauris rhoncus aenean vel elit. Turpis cursus in hac habitasse platea dictumst. Nulla porttitor massa id neque aliquam vestibulum morbi. At erat pellentesque adipiscing commodo elit at imperdiet dui In egestas erat imperdiet sed euismod nisi porta lorem mollis. Ac ut consequat semper viverra nam. Sed ullamcorper morbi tincidunt ornare massa eget egestas purus. Risus ultricies tristique nulla aliquet. Pellentesque habitant morbi tristique senectus et. Ultrices neque ornare aenean euismod elementum nisi quis eleifend.

Profit Loss: 1234

Profit Loss double tagged: 1234

Mattis rhoncus urna neque viverra justo nec ultrices. Amet tellus cras adipiscing enim. Sed arcu non odio euismod lacinia at. Odio euismod lacinia at quis risus sed vulputate odio. Ac odio tempor orci dapibus. In hac habitasse platea dictumst vestibulum rhoncus est pellentesque. Quis risus sed vulputate odio ut enim. Adipiscing commodo elit at imperdiet dui accumsan sit. Quis vel eros donec ac odio tempor orci dapibus. Turpis nunc eget lorem dolor. Dui nunc mattis enim ut tellus elementum sagittis vitae et. Facilisis sed odio morbi quis commodo. Vitae auctor eu augue ut lectus arcu. Embedded fact: 1,234,576 Iaculis nunc sed augue lacus viverra vitae congue eu consequat. Neque sodales ut etiam sit amet nisl. Dictum sit amet justo donec enim diam vulputate ut. A diam maecenas sed enim ut sem. Nisl nisi scelerisque eu ultrices vitae auctor. Purus semper eget duis at tellus at. Vehicula ipsum a arcu cursus vitae congue mauris rhoncus.

### Table formatting

Element in span with no other content | 761,123 | (461,123)
Other HTML present - cell highlighting OK | $(761,123) | £(461,123)
Other alpha numeric content present - cell highlighting not OK | 761,123 761,123 | GBP(461,123)
Border via style attribute | 761,123 | 461,123
Double border | 761,123 | 461,123
Background colour | 761,123 | 461,123

### Styled using inline stylesheet

2018 | 9,000
2017 | 8,750
2016 | 6,750
2015 | 6,500
2014 | 6,509
2013 | 5,336

### Table export test

The table below cannot be represented using the intersection of row and column aspects.

| 2018 | 2017
--- | --- | ---
Surplus | 252,867 | 14,736
Amortization and depreciation expense | 214,955 | 165,030
Manual row (periods swapped) | 14,736 | 252,867
Increase (decrease) of provisions | 27,174 | 19,596
Financial income/expense | 300 | -479
Cash flow from operating activities | -1,765,126 | 1,648,790

### Decimals/precision tests

Decimals = -3 | 137,000
Decimals = 2 | 137,456.00
Precision = 3 | 137,000
Precision = INF | 137,000.00
Decimals = INF | 137,000.00
Precision = 0 | 137,000.00137,000.00

### Scaled content in scrollable div

| 2018 | 2017 | 3 months to 31 Dec 2018 | 3 months to 31 Dec 2017
--- | --- | --- | --- | ---
Licence fee income | 123,000 | 99,000 | 35,000 | 22,000
Finance Income (Cost) | 88,000 | (67,000) | (35,000) | (22,000)